@@ -9,14 +9,12 @@ from .world import World
 
 
 class River(Thing):
-
     length = 100
     width = 2
     depth = 1
     block = mcpi.block.WATER_FLOWING
 
-    def build(self):
-
+    def create(self):
         init_x = self.position.x
         init_y = self.position.y - self.depth
         init_z = self.position.z
@@ -27,11 +25,11 @@ class River(Thing):
 
         # Find the type of land block destroyed with the river
         self._block_empty = \
-            World.server.getBlock(init_x, self.position.y - 1, init_z)
+            mcpi.block.Block(World.renderer.get_block(Vec3(init_x, self.position.y - 1, init_z)), 0)
 
-        World.server.setBlocks(
-            init_x, init_y, init_z,
-            end_x, end_y, end_z,
-            self.block)
+        self.set_blocks(
+            Vec3(init_x, init_y, init_z),
+            Vec3(end_x, end_y, end_z),
+            self.block.id)
 
         self._end_position = Vec3(end_x, self.position.y - self.depth, end_z)
