@@ -125,11 +125,9 @@ class Thing:
         :return:
         """
 
-        block = self.block
-        self.block = self._block_empty
+        self._blocks_memory.fill(self._block_empty)
+        self.render()
         self._blocks_memory.blocks = []
-        self.build()
-        self.block = block
 
     def move(self, position):
         """
